translate.storage.statistics

Package translate :: Package storage :: Module statistics |
[hide private]
[frames] | no frames]

# Module statistics

source code

Module to provide statistics and related functionality.

Organization: Zuza Software Foundation

Copyright: 2007 Zuza Software Foundation

License: GPL

Classes | [hide private]
| Statistics Manages statistics for storage objects.

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: lang, factory